#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-6lgxmFQkxrHDsyRk4Ne8lO
key:                  stack-2.9.3.1-6lgxmFQkxrHDsyRk4Ne8lO
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  065d82c801a04837b396dfbac42176aa
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-6lgxmFQkxrHDsyRk4Ne8lO
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-DloTwXdDsLxGyTkENbfyqg array-0.5.6.0
    async-2.2.6-BOzBj9OU2RsBdXVaxuDTSw
    attoparsec-0.14.4-qc2ScMijHsIVylJ0k0iua base-4.18.2.1
    base64-bytestring-1.2.1.0-LOSDeSQSndy1Y93aTSzs7h
    bytestring-0.11.5.3 casa-client-0.0.4-JOQktMHvd2p1JeZsGTEnWc
    casa-types-0.0.3-CJwxqeXq58c1AWsEBTsxYO
    colour-2.3.7-IX0onMBupCIH0yh0rKinFI
    conduit-1.3.6.1-65VBuodW2FA1U1zRKEX2Oq
    conduit-extra-1.3.8-8C1YMRPmMt82mJiP8UVrWz containers-0.6.7
    crypton-1.0.5-7t0kyZzS7otBofbnZ6zHEy
    crypton-conduit-0.2.3-1xDWfGVCIAAdmniyhCcfL deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-FxlQK29YYsT5BJApiYQGhe filepath-1.4.300.1
    fsnotify-0.4.4.0-GCC0F8bdAIR5WbyC1X4U7W
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-HEgyfacPMNACuceVjwr6rY
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    hi-file-parser-0.1.8.0-Gh0RFZS2lPN8q4ocDSiE0z
    hpack-0.38.0-6zTdnVhly0tI2tqUn0uTtW hpc-0.6.2.0
    http-client-0.7.19-4FCJ2m94wUmJsssaVohngD
    http-client-tls-0.3.6.4-K9pa9aqIB7M16aJexgoa6z
    http-conduit-2.3.9.1-KDnV8VsG74SBT5pJfJbgZK
    http-download-0.2.1.0-7hVYX15qID7WPw6Wp3sKK
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-DU0Sp6b1crZGSIhroYmYCf mtl-2.3.1
    mustache-2.4.3.1-AmQuh793Wat2ExtCKkoLq4
    neat-interpolation-0.5.1.4-1wdgBCXenFOjCEnpiBYYK
    network-uri-2.6.4.2-1CJs0qlSGKv7cmTNxU9YR0
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    pantry-0.8.3-De3f1qSnlIxE9TOjVFJh6X
    path-0.9.6-GztXZKf17iiBydBxqKmqaR
    path-io-1.8.2-4BGDxXhcnF7GZy9alBMQfx
    persistent-2.14.6.1-CXYeTUPLnecB49WmzMNtSU
    persistent-sqlite-2.13.3.0-BAXvqHfzQeuKfxq9f8dtbj pretty-1.1.3.6
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5 process-1.6.19.0
    project-template-0.2.1.0-CHT6WRyp6jhL1uopVn0kJn
    random-1.2.1.3-JQ5HMleih0QHEX58PgSIMQ
    retry-0.9.3.1-5vTIPhi2r08CzV6yedSxG1
    rio-0.1.25.0-A1xmpAj0yy03sIARUcpHUN
    rio-prettyprint-0.1.9.0-6OLYwOPxftsA6SK0py31NL
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG stm-2.5.1.0
    streaming-commons-0.2.3.1-IqBBzbpSoGCJEYKz1sdGdv
    tar-0.6.0.0-4Kg67oe22eeFzP0nDqvQeZ template-haskell-2.20.0.0
    temporary-1.3-1ezn4dc6wi13jwuWHEP4w4 text-2.0.2
    text-metrics-0.3.3-5tGUa8zhnfk4dWBT7ycbs0
    th-reify-many-0.1.10-8Nvnir9UCWY1kL1Paof88g time-1.12.2
    tls-2.0.6-FQiPxWmwiH9GFLE7mjeD2P transformers-0.6.1.0
    typed-process-0.2.13.0-GtejE0dV6Pb8vHOx8VaDLt
    unicode-transforms-0.4.0.1-CFPMfV25NHO2hSjBzBaoi8 unix-2.8.4.0
    unix-compat-0.7.4.1-EyHNw9oGSnZGifmmgNTG2S
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7
    yaml-0.11.11.2-7C8te7oEKag5lil8hT24q7
    zip-archive-0.4.3.2-HOJElStBDZC4LyBWVIWbJN
    zlib-0.7.1.1-D2e2i4PjHPPGlB4wotxVYg

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

